@@ -67,6 +67,7 @@ new CloudFrontToMediaStore(this, "test-cloudfront-mediastore-default", new Cloud
 |mediaStoreContainerProps?|[`mediastore.CfnContainerProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_mediastore.CfnContainerProps.html)|Optional user provided props to override the default props for the MediaStore Container.|
 |cloudFrontDistributionProps?|[`cloudfront.DistributionProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cloudfront.DistributionProps.html)|`any`|Optional user provided props to override the default props for the CloudFront Distribution.|
 |insertHttpSecurityHeaders?|`boolean`|Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from CloudFront|
+| responseHeadersPolicyProps?   | [`cloudfront.ResponseHeadersPolicyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_cloudfront.ResponseHeadersPolicyProps.html) | Optional user provided configuration that cloudfront applies to all http responses.|
 |cloudFrontLoggingBucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_s3.BucketProps.html)|Optional user provided props to override the default props for the CloudFront Logging Bucket.|
 
 ## Pattern Properties
@@ -145,6 +146,7 @@ class CloudFrontToMediaStore(
         existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
         media_store_container_props: typing.Optional[typing.Union[aws_cdk.aws_mediastore.CfnContainerProps, typing.Dict[str, typing.Any]]] = None,
+        response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -152,15 +154,28 @@ class CloudFrontToMediaStore(
         :param cloud_front_distribution_props: Optional user provided props to override the default props for the CloudFront. Default: - Default props are used
         :param cloud_front_logging_bucket_props: Optional user provided props to override the default props for the CloudFront Logging Bucket. Default: - Default props are used
         :param existing_media_store_container_obj: Existing instance of mediastore.CfnContainer obejct. Default: - None
-        :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
+        :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Turning this on will inject default headers and is mutually exclusive with passing custom security headers via the responseHeadersPolicyProps parameter. Default: - true
         :param media_store_container_props: Optional user provided props to override the default props for the MediaStore. Default: - Default props are used
+        :param response_headers_policy_props: Optional user provided configuration that cloudfront applies to all http responses. Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or ResponseHeadersCorsBehavior to the cloudfront distribution. Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers via ``insertHttpSecurityHeaders`` prop. Will throw an error if both ``insertHttpSecurityHeaders`` is set to ``true`` and ResponseSecurityHeadersBehavior is passed. Default: - undefined
 
         :access: public
         :since: 1.76.0
         :summary: Constructs a new instance of CloudFrontToMediaStore class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudFrontToMediaStore.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                cloud_front_distribution_props: typing.Any = None,
+                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
+                insert_http_security_headers: typing.Optional[builtins.bool] = None,
+                media_store_container_props: typing.Optional[typing.Union[aws_cdk.aws_mediastore.CfnContainerProps, typing.Dict[str, typing.Any]]] = None,
+                response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontToMediaStoreProps(
@@ -169,6 +184,7 @@ class CloudFrontToMediaStore(
             existing_media_store_container_obj=existing_media_store_container_obj,
             insert_http_security_headers=insert_http_security_headers,
             media_store_container_props=media_store_container_props,
+            response_headers_policy_props=response_headers_policy_props,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -217,6 +233,7 @@ class CloudFrontToMediaStore(
         "existing_media_store_container_obj": "existingMediaStoreContainerObj",
         "insert_http_security_headers": "insertHttpSecurityHeaders",
         "media_store_container_props": "mediaStoreContainerProps",
+        "response_headers_policy_props": "responseHeadersPolicyProps",
     },
 )
 class CloudFrontToMediaStoreProps:
@@ -228,13 +245,15 @@ class CloudFrontToMediaStoreProps:
         existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
         media_store_container_props: typing.Optional[typing.Union[aws_cdk.aws_mediastore.CfnContainerProps, typing.Dict[str, typing.Any]]] = None,
+        response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param cloud_front_distribution_props: Optional user provided props to override the default props for the CloudFront. Default: - Default props are used
         :param cloud_front_logging_bucket_props: Optional user provided props to override the default props for the CloudFront Logging Bucket. Default: - Default props are used
         :param existing_media_store_container_obj: Existing instance of mediastore.CfnContainer obejct. Default: - None
-        :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
+        :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Turning this on will inject default headers and is mutually exclusive with passing custom security headers via the responseHeadersPolicyProps parameter. Default: - true
         :param media_store_container_props: Optional user provided props to override the default props for the MediaStore. Default: - Default props are used
+        :param response_headers_policy_props: Optional user provided configuration that cloudfront applies to all http responses. Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or ResponseHeadersCorsBehavior to the cloudfront distribution. Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers via ``insertHttpSecurityHeaders`` prop. Will throw an error if both ``insertHttpSecurityHeaders`` is set to ``true`` and ResponseSecurityHeadersBehavior is passed. Default: - undefined
 
         :summary: The properties for the CloudFrontToMediaStore Construct
         '''
@@ -242,13 +261,26 @@ class CloudFrontToMediaStoreProps:
             cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
         if isinstance(media_store_container_props, dict):
             media_store_container_props = aws_cdk.aws_mediastore.CfnContainerProps(**media_store_container_props)
+        if isinstance(response_headers_policy_props, dict):
+            response_headers_policy_props = aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps(**response_headers_policy_props)
         if __debug__:
-            type_hints = typing.get_type_hints(CloudFrontToMediaStoreProps.__init__)
+            def stub(
+                *,
+                cloud_front_distribution_props: typing.Any = None,
+                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
+                insert_http_security_headers: typing.Optional[builtins.bool] = None,
+                media_store_container_props: typing.Optional[typing.Union[aws_cdk.aws_mediastore.CfnContainerProps, typing.Dict[str, typing.Any]]] = None,
+                response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
             check_type(argname="argument cloud_front_logging_bucket_props", value=cloud_front_logging_bucket_props, expected_type=type_hints["cloud_front_logging_bucket_props"])
             check_type(argname="argument existing_media_store_container_obj", value=existing_media_store_container_obj, expected_type=type_hints["existing_media_store_container_obj"])
             check_type(argname="argument insert_http_security_headers", value=insert_http_security_headers, expected_type=type_hints["insert_http_security_headers"])
             check_type(argname="argument media_store_container_props", value=media_store_container_props, expected_type=type_hints["media_store_container_props"])
+            check_type(argname="argument response_headers_policy_props", value=response_headers_policy_props, expected_type=type_hints["response_headers_policy_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if cloud_front_distribution_props is not None:
             self._values["cloud_front_distribution_props"] = cloud_front_distribution_props
@@ -260,6 +292,8 @@ class CloudFrontToMediaStoreProps:
             self._values["insert_http_security_headers"] = insert_http_security_headers
         if media_store_container_props is not None:
             self._values["media_store_container_props"] = media_store_container_props
+        if response_headers_policy_props is not None:
+            self._values["response_headers_policy_props"] = response_headers_policy_props
 
     @builtins.property
     def cloud_front_distribution_props(self) -> typing.Any:
@@ -296,6 +330,9 @@ class CloudFrontToMediaStoreProps:
     def insert_http_security_headers(self) -> typing.Optional[builtins.bool]:
         '''Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
 
+        Turning this on will inject default headers and is mutually exclusive with passing custom security headers
+        via the responseHeadersPolicyProps parameter.
+
         :default: - true
         '''
         result = self._values.get("insert_http_security_headers")
@@ -312,6 +349,24 @@ class CloudFrontToMediaStoreProps:
         result = self._values.get("media_store_container_props")
         return typing.cast(typing.Optional[aws_cdk.aws_mediastore.CfnContainerProps], result)
 
+    @builtins.property
+    def response_headers_policy_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps]:
+        '''Optional user provided configuration that cloudfront applies to all http responses.
+
+        Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or
+        ResponseHeadersCorsBehavior to the cloudfront distribution.
+
+        Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers
+        via ``insertHttpSecurityHeaders`` prop. Will throw an error if both ``insertHttpSecurityHeaders`` is set to ``true``
+        and ResponseSecurityHeadersBehavior is passed.
+
+        :default: - undefined
+        '''
+        result = self._values.get("response_headers_policy_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
